@@ -76,27 +76,15 @@ bool KExiv2::supportMetadataWritting(const TQString& typeMime)
     }
     else if (typeMime == TQString("image/tiff"))
     {
-#if (EXIV2_TEST_VERSION(0,17,91))
         return true;
-#else
-        return false;
-#endif
     }
     else if (typeMime == TQString("image/png"))
     {
-#if (EXIV2_TEST_VERSION(0,17,91))
         return true;
-#else
-        return false;
-#endif
     }
     else if (typeMime == TQString("image/jp2"))
     {
-#if (EXIV2_TEST_VERSION(0,17,91))
         return true;
-#else
-        return false;
-#endif
     }
 
     return false;
@@ -112,13 +100,7 @@ TQString KExiv2::Exiv2Version()
     // Since 0.14.0 release, we can extract run-time version of Exiv2.
     // else we return make version.
 
-#if (EXIV2_TEST_VERSION(0,14,0))
     return TQString(Exiv2::version());
-#else
-    return TQString("%1.%2.%3").arg(EXIV2_MAJOR_VERSION)
-                              .arg(EXIV2_MINOR_VERSION)
-                              .arg(EXIV2_PATCH_VERSION);
-#endif
 }
 
 bool KExiv2::clearComments()
@@ -177,21 +159,12 @@ TQByteArray KExiv2::getExif() const
     {
         if (!d->exifMetadata.empty())
         {
-
             Exiv2::ExifData& exif = d->exifMetadata;
-
-#if (EXIV2_TEST_VERSION(0,17,91))
             Exiv2::Blob blob;
             Exiv2::ExifParser::encode(blob, Exiv2::bigEndian, exif);
             TQByteArray ba(blob.size());
             if (ba.size())
                 memcpy(ba.data(), (const char*)&blob[0], blob.size());
-#else
-            Exiv2::DataBuf c2 = exif.copy();
-            TQByteArray ba(c2.size_);
-            if (ba.size())
-                memcpy(ba.data(), c2.pData_, c2.size_);
-#endif
 
             return ba;
         }
@@ -218,25 +191,22 @@ TQByteArray KExiv2::getIptc(bool addIrbHeader) const
 
             if (addIrbHeader)
             {
-#if (EXIV2_TEST_VERSION(0,10,0))
                 c2 = Exiv2::Photoshop::setIptcIrb(0, 0, iptc);
-#else
-                tqDebug("Exiv2 version is to old. Cannot add Irb header to IPTC metadata");
-                return TQByteArray();
-#endif
             }
             else
             {
-#if (EXIV2_TEST_VERSION(0,17,91))
                 c2 = Exiv2::IptcParser::encode(d->iptcMetadata);
-#else
-                c2 = iptc.copy();
-#endif
             }
 
+#if (EXIV2_TEST_VERSION(0,28,0))
+            TQByteArray data(c2.size());
+            if (data.size())
+                memcpy(data.data(), c2.c_data(), c2.size());
+#else
             TQByteArray data(c2.size_);
             if (data.size())
                 memcpy(data.data(), c2.pData_, c2.size_);
+#endif
             return data;
         }
     }
@@ -263,15 +233,8 @@ bool KExiv2::setExif(const TQByteArray& data)
     {
         if (!data.isEmpty())
         {
-#if (EXIV2_TEST_VERSION(0,17,91))
             Exiv2::ExifParser::decode(d->exifMetadata, (const Exiv2::byte*)data.data(), data.size());
             return (!d->exifMetadata.empty());
-#else
-            if (d->exifMetadata.load((const Exiv2::byte*)data.data(), data.size()) != 0)
-                return false;
-            else
-                return true;
-#endif
         }
     }
     catch( Exiv2::Error &e )
@@ -291,15 +254,8 @@ bool KExiv2::setIptc(const TQByteArray& data)
     {
         if (!data.isEmpty())
         {
-#if (EXIV2_TEST_VERSION(0,17,91))
             Exiv2::IptcParser::decode(d->iptcMetadata, (const Exiv2::byte*)data.data(), data.size());
             return (!d->iptcMetadata.empty());
-#else
-            if (d->iptcMetadata.load((const Exiv2::byte*)data.data(), data.size()) != 0)
-                return false;
-            else
-                return true;
-#endif
         }
     }
     catch( Exiv2::Error &e )
@@ -321,7 +277,11 @@ bool KExiv2::load(const TQByteArray& imgData)
     try
     {
 
+#if (EXIV2_TEST_VERSION(0,28,0))
+        Exiv2::Image::UniquePtr image = Exiv2::ImageFactory::open((Exiv2::byte*)imgData.data(), imgData.size());
+#else
         Exiv2::Image::AutoPtr image = Exiv2::ImageFactory::open((Exiv2::byte*)imgData.data(), imgData.size());
+#endif
         d->filePath = TQString();
         image->readMetadata();
 
@@ -359,8 +319,13 @@ bool KExiv2::load(const TQString& filePath)
     try
     {
 
+#if (EXIV2_TEST_VERSION(0,28,0))
+        Exiv2::Image::UniquePtr image = Exiv2::ImageFactory::open((const char*)
+                                        (TQFile::encodeName(filePath)));
+#else
         Exiv2::Image::AutoPtr image = Exiv2::ImageFactory::open((const char*)
                                       (TQFile::encodeName(filePath)));
+#endif
         d->filePath = filePath;
         image->readMetadata();
 
@@ -418,8 +383,13 @@ bool KExiv2::save(const TQString& filePath)
     try
     {
         Exiv2::AccessMode mode;
+#if (EXIV2_TEST_VERSION(0,28,0))
+        Exiv2::Image::UniquePtr image = Exiv2::ImageFactory::open((const char*)
+                                        (TQFile::encodeName(filePath)));
+#else
         Exiv2::Image::AutoPtr image = Exiv2::ImageFactory::open((const char*)
                                       (TQFile::encodeName(filePath)));
+#endif
 
         // We need to load target file metadata to merge with new one. It's mandatory with TIFF format:
         // like all tiff file structure is based on Exif.
@@ -509,8 +479,8 @@ bool KExiv2::save(const TQString& filePath)
 bool KExiv2::applyChanges()
 {
     if (d->filePath.isEmpty())
-	return false;
-	
+        return false;
+
     return save(d->filePath);
 }
 
@@ -532,8 +502,13 @@ bool KExiv2::canWriteComment(const TQString& filePath)
 {
     try
     {
+#if (EXIV2_TEST_VERSION(0,28,0))
+        Exiv2::Image::UniquePtr image = Exiv2::ImageFactory::open((const char*)
+                                        (TQFile::encodeName(filePath)));
+#else
         Exiv2::Image::AutoPtr image = Exiv2::ImageFactory::open((const char*)
                                       (TQFile::encodeName(filePath)));
+#endif
 
         Exiv2::AccessMode mode = image->checkMode(Exiv2::mdComment);
         return (mode == Exiv2::amWrite || mode == Exiv2::amReadWrite);
@@ -541,7 +516,7 @@ bool KExiv2::canWriteComment(const TQString& filePath)
     catch( Exiv2::Error &e )
     {
         std::string s(e.what());
-        tqDebug("%s (Error #%i: %s)", "Cannot check Comment access mode using Exiv2 ", e.code(), s.c_str());
+        tqDebug("%s (Error #%i: %s)", "Cannot check Comment access mode using Exiv2 ", (int)e.code(), s.c_str());
     }
 
     return false;
@@ -551,8 +526,13 @@ bool KExiv2::canWriteExif(const TQString& filePath)
 {
     try
     {
+#if (EXIV2_TEST_VERSION(0,28,0))
+        Exiv2::Image::UniquePtr image = Exiv2::ImageFactory::open((const char*)
+                                        (TQFile::encodeName(filePath)));
+#else
         Exiv2::Image::AutoPtr image = Exiv2::ImageFactory::open((const char*)
                                       (TQFile::encodeName(filePath)));
+#endif
 
         Exiv2::AccessMode mode = image->checkMode(Exiv2::mdExif);
         return (mode == Exiv2::amWrite || mode == Exiv2::amReadWrite);
@@ -560,7 +540,7 @@ bool KExiv2::canWriteExif(const TQString& filePath)
     catch( Exiv2::Error &e )
     {
         std::string s(e.what());
-        tqDebug("%s (Error #%i: %s)", "Cannot check Exif access mode using Exiv2 ", e.code(), s.c_str());
+        tqDebug("%s (Error #%i: %s)", "Cannot check Exif access mode using Exiv2 ", (int)e.code(), s.c_str());
     }
 
     return false;
@@ -570,8 +550,13 @@ bool KExiv2::canWriteIptc(const TQString& filePath)
 {
     try
     {
+#if (EXIV2_TEST_VERSION(0,28,0))
+        Exiv2::Image::UniquePtr image = Exiv2::ImageFactory::open((const char*)
+                                        (TQFile::encodeName(filePath)));
+#else
         Exiv2::Image::AutoPtr image = Exiv2::ImageFactory::open((const char*)
                                       (TQFile::encodeName(filePath)));
+#endif
 
         Exiv2::AccessMode mode = image->checkMode(Exiv2::mdIptc);
         return (mode == Exiv2::amWrite || mode == Exiv2::amReadWrite);
@@ -579,7 +564,7 @@ bool KExiv2::canWriteIptc(const TQString& filePath)
     catch( Exiv2::Error &e )
     {
         std::string s(e.what());
-        tqDebug("%s (Error #%i: %s)", "Cannot check Iptc access mode using Exiv2 ", e.code(), s.c_str());
+        tqDebug("%s (Error #%i: %s)", "Cannot check Iptc access mode using Exiv2 ", (int)e.code(), s.c_str());
     }
 
     return false;
@@ -591,12 +576,10 @@ bool KExiv2::setImageProgramId(const TQString& program, const TQString& version)
     {
         // Record program info in Exif.Image.ProcessingSoftware tag (only available with Exiv2 >= 0.14.0).
 
-#if (EXIV2_TEST_VERSION(0,14,0))
         TQString software(program);
         software.append("-");
         software.append(version);
         d->exifMetadata["Exif.Image.ProcessingSoftware"] = software.ascii();
-#endif
 
         // See B.K.O #142564: Check if Exif.Image.Software already exist. If yes, do not touch this tag.
 
@@ -636,7 +619,11 @@ TQSize KExiv2::getImageDimensions() const
 
     try
     {
+#if (EXIV2_TEST_VERSION(0,28,0))
+        int64_t width=-1, height=-1;
+#else
         long width=-1, height=-1;
+#endif
 
         // Try to get Exif.Photo tags
 
@@ -645,13 +632,25 @@ TQSize KExiv2::getImageDimensions() const
         Exiv2::ExifData::iterator it = exifData.findKey(key);
 
         if (it != exifData.end())
+        {
+#if (EXIV2_TEST_VERSION(0,28,0))
+            width = it->toInt64();
+#else
             width = it->toLong();
+#endif
+        }
 
         Exiv2::ExifKey key2("Exif.Photo.PixelYDimension");
         Exiv2::ExifData::iterator it2 = exifData.findKey(key2);
 
         if (it2 != exifData.end())
+        {
+#if (EXIV2_TEST_VERSION(0,28,0))
+            height = it2->toInt64();
+#else
             height = it2->toLong();
+#endif
+        }
 
         if (width != -1 && height != -1)
             return TQSize(width, height);
@@ -665,13 +664,25 @@ TQSize KExiv2::getImageDimensions() const
         Exiv2::ExifData::iterator it3 = exifData.findKey(key3);
 
         if (it3 != exifData.end())
+        {
+#if (EXIV2_TEST_VERSION(0,28,0))
+            width = it3->toInt64();
+#else
             width = it3->toLong();
+#endif
+        }
 
         Exiv2::ExifKey key4("Exif.Image.ImageLength");
         Exiv2::ExifData::iterator it4 = exifData.findKey(key4);
 
         if (it4 != exifData.end())
+        {
+#if (EXIV2_TEST_VERSION(0,28,0))
+            height = it4->toInt64();
+#else
             height = it4->toLong();
+#endif
+        }
 
         if (width != -1 && height != -1)
             return TQSize(width, height);
@@ -715,13 +726,13 @@ TQImage KExiv2::getExifThumbnail(bool fixOrientation) const
 
     try
     {
-#if (EXIV2_TEST_VERSION(0,17,91))
         Exiv2::ExifThumbC thumb(d->exifMetadata);
         Exiv2::DataBuf const c1 = thumb.copy();
+#if (EXIV2_TEST_VERSION(0,28,0))
+        thumbnail.loadFromData(c1.c_data(), c1.size());
 #else
-        Exiv2::DataBuf const c1(d->exifMetadata.copyThumbnail());
-#endif
         thumbnail.loadFromData(c1.pData_, c1.size_);
+#endif
 
         if (!thumbnail.isNull())
         {
@@ -733,7 +744,11 @@ TQImage KExiv2::getExifThumbnail(bool fixOrientation) const
                 if (it != exifData.end())
                 {
                     TQWMatrix matrix;
+#if (EXIV2_TEST_VERSION(0,28,0))
+                    int64_t orientation = it->toInt64();
+#else
                     long orientation = it->toLong();
+#endif
                     tqDebug("Exif Thumbnail Qt::Orientation: %i", (int)orientation);
 
                     switch (orientation)
@@ -795,21 +810,12 @@ bool KExiv2::setExifThumbnail(const TQImage& thumb, bool setProgramName)
 
     try
     {
-#if (EXIV2_TEST_VERSION(0,17,91))
         TQByteArray data;
         TQBuffer buffer(data);
         buffer.open(IO_WriteOnly);
         thumb.save(&buffer, "JPEG");
         Exiv2::ExifThumb thumb(d->exifMetadata);
         thumb.setJpegThumbnail((Exiv2::byte *)data.data(), data.size());
-#else
-        KTempFile thumbFile(TQString(), "KExiv2ExifThumbnail");
-        thumbFile.setAutoDelete(true);
-        thumb.save(thumbFile.name(), "JPEG");
-
-        const std::string &fileName( (const char*)(TQFile::encodeName(thumbFile.name())) );
-        d->exifMetadata.setJpegThumbnail( fileName );
-#endif
         return true;
     }
     catch( Exiv2::Error &e )
@@ -842,7 +848,11 @@ KExiv2::ImageOrientation KExiv2::getImageOrientation() const
     {
         Exiv2::ExifData exifData(d->exifMetadata);
         Exiv2::ExifData::iterator it;
+#if (EXIV2_TEST_VERSION(0,28,0))
+        int64_t orientation;
+#else
         long orientation;
+#endif
         ImageOrientation imageOrient = ORIENTATION_NORMAL;
 
         // Because some camera set a wrong standard exif orientation tag,
@@ -857,7 +867,11 @@ KExiv2::ImageOrientation KExiv2::getImageOrientation() const
 
             if (it != exifData.end())
             {
+#if (EXIV2_TEST_VERSION(0,28,0))
+                orientation = it->toInt64();
+#else
                 orientation = it->toLong();
+#endif
                 tqDebug("Minolta Makernote Qt::Orientation: %i", (int)orientation);
                 switch(orientation)
                 {
@@ -876,7 +890,11 @@ KExiv2::ImageOrientation KExiv2::getImageOrientation() const
 
             if (it != exifData.end())
             {
+#if (EXIV2_TEST_VERSION(0,28,0))
+                orientation = it->toInt64();
+#else
                 orientation = it->toLong();
+#endif
                 tqDebug("Minolta Makernote Qt::Orientation: %i", (int)orientation);
                 switch(orientation)
                 {
@@ -898,7 +916,11 @@ KExiv2::ImageOrientation KExiv2::getImageOrientation() const
 
         if (it != exifData.end())
         {
+#if (EXIV2_TEST_VERSION(0,28,0))
+            orientation = it->toInt64();
+#else
             orientation = it->toLong();
+#endif
             tqDebug("Exif Qt::Orientation: %i", (int)orientation);
             return (ImageOrientation)orientation;
         }
@@ -1279,15 +1301,9 @@ TQString KExiv2::getExifTagString(const char* exifTagName, bool escapeCR) const
         Exiv2::ExifData::iterator it = exifData.findKey(exifKey);
         if (it != exifData.end())
         {
-#if (EXIV2_TEST_VERSION(0,17,91))
             // See B.K.O #184156 comment #13
             std::string val  = it->print(&exifData);
             TQString tagValue = TQString::fromLocal8Bit(val.c_str());
-#else
-            std::ostringstream os;
-            os << *it;
-            TQString tagValue = TQString::fromLocal8Bit(os.str().c_str());
-#endif
             if (escapeCR)
                 tagValue.replace("\n", " ");
 
@@ -1376,7 +1392,11 @@ bool KExiv2::getExifTagLong(const char* exifTagName, long &val) const
         Exiv2::ExifData::iterator it = exifData.findKey(exifKey);
         if (it != exifData.end())
         {
+#if (EXIV2_TEST_VERSION(0,28,0))
+            val = (long)it->toInt64();
+#else
             val = it->toLong();
+#endif
             return true;
         }
     }
@@ -1401,11 +1421,7 @@ TQByteArray KExiv2::getExifTagData(const char* exifTagName) const
             TQByteArray data((*it).size());
             if (data.size())
             {
-#if (EXIV2_TEST_VERSION(0,17,91))
                 (*it).copy((Exiv2::byte*)data.data(), Exiv2::bigEndian);
-#else
-                (*it).copy((Exiv2::byte*)data.data(), exifData.byteOrder());
-#endif
             }
             return data;
         }
@@ -1603,11 +1619,7 @@ TQString KExiv2::getExifTagTitle(const char *exifTagName)
     {
         std::string exifkey(exifTagName);
         Exiv2::ExifKey ek(exifkey);
-#if EXIV2_TEST_VERSION(0, 21, 0)
         return TQString::fromLocal8Bit( ek.tagLabel().c_str() );
-#else
-        return TQString::fromLocal8Bit( Exiv2::ExifTags::tagTitle(ek.tag(), ek.ifdId()) );
-#endif
     }
     catch (Exiv2::Error& e)
     {
@@ -1623,11 +1635,7 @@ TQString KExiv2::getExifTagDescription(const char *exifTagName)
     {
         std::string exifkey(exifTagName);
         Exiv2::ExifKey ek(exifkey);
-#if EXIV2_TEST_VERSION(0, 21, 0)
         return TQString::fromLocal8Bit( ek.tagDesc().c_str() );
-#else
-        return TQString::fromLocal8Bit( Exiv2::ExifTags::tagDesc(ek.tag(), ek.ifdId()) );
-#endif
     }
     catch (Exiv2::Error& e)
     {
@@ -1912,7 +1920,11 @@ bool KExiv2::setGPSInfo(double altitude, double latitude, double longitude, bool
         // Do all the easy constant ones first.
         // GPSVersionID tag: standard says is should be four bytes: 02 00 00 00
         // (and, must be present).
+#if (EXIV2_TEST_VERSION(0,28,0))
+        Exiv2::Value::UniquePtr value = Exiv2::Value::create(Exiv2::unsignedByte);
+#else
         Exiv2::Value::AutoPtr value = Exiv2::Value::create(Exiv2::unsignedByte);
+#endif
         value->read("2 0 0 0");
         d->exifMetadata.add(Exiv2::ExifKey("Exif.GPSInfo.GPSVersionID"), value.get());
 
@@ -2180,7 +2192,11 @@ bool KExiv2::setImageKeywords(const TQStringList& oldKeywords, const TQStringLis
             TQString key = *it;
             key.truncate(64);
 
+#if (EXIV2_TEST_VERSION(0,28,0))
+            Exiv2::Value::UniquePtr val = Exiv2::Value::create(Exiv2::string);
+#else
             Exiv2::Value::AutoPtr val = Exiv2::Value::create(Exiv2::string);
+#endif
             val->read(key.latin1());
             iptcData.add(iptcTag, val.get());
         }
@@ -2263,7 +2279,11 @@ bool KExiv2::setImageSubjects(const TQStringList& oldSubjects, const TQStringLis
             TQString key = *it;
             key.truncate(236);
 
+#if (EXIV2_TEST_VERSION(0,28,0))
+            Exiv2::Value::UniquePtr val = Exiv2::Value::create(Exiv2::string);
+#else
             Exiv2::Value::AutoPtr val = Exiv2::Value::create(Exiv2::string);
+#endif
             val->read(key.latin1());
             iptcData.add(iptcTag, val.get());
         }
@@ -2347,7 +2367,11 @@ bool KExiv2::setImageSubCategories(const TQStringList& oldSubCategories, const T
             TQString key = *it;
             key.truncate(32);
 
+#if (EXIV2_TEST_VERSION(0,28,0))
+            Exiv2::Value::UniquePtr val = Exiv2::Value::create(Exiv2::string);
+#else
             Exiv2::Value::AutoPtr val = Exiv2::Value::create(Exiv2::string);
+#endif
             val->read(key.latin1());
             iptcData.add(iptcTag, val.get());
         }
